@@ -1,13 +1,8 @@
 # coding: utf8
 from __future__ import unicode_literals
 
-import pytest
-
-import spacy
-
 from spacy.lang.en import English
 from spacy.pipeline import EntityRuler
-from spacy.tokens import Span
 
 
 def test_issue4267():
